@@ -60,10 +60,9 @@ applied <- 'processing options applied:\n'
 
 if (any(opt=='none')) {
   opt <- 'none' # remove other opt arguments (so they are not called further on, but still allowing for fixneg to work)
-  applied <- 'No relevant processing option entered; returning raw values\n'
-#  rspecdata <- rspecdata
-#  class(rspecdata) <- c('rspec', 'data.frame')
-#	return(rspecdata)
+  
+  if(fixneg=='none')
+    stop('No processing options selected')
   }
 
 wl_index <- which(names(rspecdata)=='wl')
@@ -94,7 +93,7 @@ if (fixneg=='addmin'){
 
 if (fixneg=='zero'){
   rspecdata[rspecdata < 0 ] <- 0
-  applied <- c(applied, 'Negative value correction: added min to all reflectance\n')
+  applied <- c(applied, 'Negative value correction: converted negative values to zero\n')
 }
 
 if (any(opt=='smooth')){
