@@ -8,7 +8,7 @@
 #' 
 #' @export
 
-tcsvol <- function(tcsdata, col='black', grid=T, fill=T){
+tcsvol <- function(tcsdata, col='black', alpha=0.2, grid.alpha=1, grid=T, fill=T){
 
 # if(class(tcsdata)=='tcs'){
   # dat <- tcsdata$tcs  
@@ -25,11 +25,11 @@ if(grid==T){
   for(i in 1:nrow(ppairs)){
       segments3d(coords[ppairs[i,],'x'], 
                  coords[ppairs[i,],'y'],
-                 coords[ppairs[i,],'z'], color=col)
+                 coords[ppairs[i,],'z'], color=col, alpha=grid.alpha)
   }
 }
 
 if(fill==T)
-rgl.triangles(coords[vol,1],coords[vol,2],coords[vol,3], alpha=0.2, color=col)
+rgl.triangles(coords[vol,1],coords[vol,2],coords[vol,3], alpha=alpha, color=col)
 material3d(alpha=1)
 }
